<?php
ob_start();
ini_set('session.cookie_httponly', 1);
ini_set('session.cookie_secure', 1);
header('X-Content-Type-Options: nosniff');
header('X-Frame-Options: DENY');
header('X-XSS-Protection: 1; mode=block');
header('Content-Security-Policy: default-src \'self\'; style-src \'self\' \'unsafe-inline\';');
header('Strict-Transport-Security: max-age=31536000; includeSubDomains');
session_start();

$debug = [];
try {
    $config = require 'config.php';
    $debug[] = "Config loaded";
    
    $db = new PDO(
        "mysql:host={$config['db']['host']};dbname={$config['db']['name']}", 
        $config['db']['user'], 
        $config['db']['pass']
    );
    $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    $debug[] = "Database connected";
} catch (PDOException $e) {
    $debug[] = "Database error: " . $e->getMessage();
    die("Database connection error: " . $e->getMessage());
}

$error = '';
$success = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $username = filter_input(INPUT_POST, 'username', FILTER_SANITIZE_STRING);
    $password = filter_input(INPUT_POST, 'password', FILTER_SANITIZE_STRING);
    
    $debug[] = "Login attempt for: " . $username;

    if ($username && $password) {
        try {
            $stmt = $db->prepare('SELECT id, password, is_blocked, login_attempts, last_attempt FROM users WHERE username = ?');
            $stmt->execute([$username]);
            $user = $stmt->fetch(PDO::FETCH_ASSOC);
            
            $debug[] = "User found: " . ($user ? 'yes' : 'no');

            if ($user) {
                if ($user['is_blocked']) {
                    $error = 'Account is blocked';
                    $debug[] = "Account blocked";
                } else if ($user['login_attempts'] >= 5 && strtotime($user['last_attempt']) > strtotime('-15 minutes')) {
                    $error = 'Too many login attempts';
                    $debug[] = "Too many attempts";
                } else if (password_verify($password, $user['password'])) {
                    $stmt = $db->prepare('UPDATE users SET login_attempts = 0, last_attempt = NOW() WHERE id = ?');
                    $stmt->execute([$user['id']]);
                    $_SESSION['user_id'] = $user['id'];
                    $_SESSION['username'] = $username;
                    $debug[] = "Login successful";
                    header('Location: index.php');
                    exit;
                } else {
                    $stmt = $db->prepare('UPDATE users SET login_attempts = login_attempts + 1, last_attempt = NOW() WHERE id = ?');
                    $stmt->execute([$user['id']]);
                    $error = 'Invalid password';
                    $debug[] = "Invalid password";
                }
            } else {
                $error = 'User not found';
                $debug[] = "User not found";
            }
        } catch (PDOException $e) {
            $error = 'Server error';
            $debug[] = "SQL Error: " . $e->getMessage();
            $debug[] = "SQL State: " . $e->getCode();
        }
    }
}
?>
<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <title>Text0Nly - Login</title>
    <style>
        body { font-family: Arial, sans-serif; max-width: 400px; margin: 20px auto; padding: 20px; }
        .form-group { margin: 10px 0; }
        input { width: 100%; padding: 8px; margin: 5px 0; }
        button { width: 100%; padding: 10px; background: #2196F3; color: white; border: none; cursor: pointer; }
        .error { color: red; }
        .success { color: green; }
        .debug { background: #f5f5f5; padding: 10px; margin: 10px 0; font-family: monospace; }
    </style>
</head>
<body>
    <h2>Login</h2>
    <?php if ($error): ?>
        <div class="error"><?= htmlspecialchars($error) ?></div>
    <?php endif; ?>
    <?php if ($success): ?>
        <div class="success"><?= htmlspecialchars($success) ?></div>
    <?php endif; ?>
    
    <form method="post">
        <div class="form-group">
            <input type="text" name="username" placeholder="Username" required>
        </div>
        <div class="form-group">
            <input type="password" name="password" placeholder="Password" required>
        </div>
        <button type="submit">Login</button>
    </form>
    <p><a href="register.php">Register</a> | <a href="index.php">Back to chat</a></p>
    
    <?php if (!empty($debug)): ?>
        <div class="debug">
            <strong>Debug info:</strong><br>
            <?php foreach ($debug as $line): ?>
                <?= htmlspecialchars($line) ?><br>
            <?php endforeach; ?>
        </div>
    <?php endif; ?>
</body>
</html>
<?php ob_end_flush(); ?> 